Learn R Programming

StealLikeBayes (version 1.0)

StealLikeBayes-package: A Compendium of Bayesian Statistical Routines Written in C++

Description

This is a compendium of C++ routines useful for Bayesian statistics. We steal other people's C++ code, repurpose it, and export it so developers of R packages can use it in their C++ code. We actually don't steal anything, or claim that Thomas Bayes did, but copy code that is compatible with our GPL 3 licence, fully acknowledging the authorship of the original code.

Arguments

Author

Maintainer: Tomasz Woźniak wozniak.tom@pm.me (ORCID) (contributions: rnorm1_precision_sampler, rgennorm)

Authors:

See Also