This is a compendium of C++ routines useful for Bayesian statistics. We steal other people's C++ code, repurpose it, and export it so developers of R packages can use it in their C++ code. We actually don't steal anything, or claim that Thomas Bayes did, but copy code that is compatible with our GPL 3 licence, fully acknowledging the authorship of the original code.
Maintainer: Tomasz Woźniak wozniak.tom@pm.me (ORCID) (contributions: rnorm1_precision_sampler, rgennorm)
Authors:
Xiaolei Wang adamwang15@gmail.com (ORCID) (contributions: rhaar1)
Longcan Li longcando@outlook.com (ORCID) (contributions: sample_variances_horseshoe)
Jianying Shelly Xie shellyyinggxie@gmail.com (ORCID) (contributions: sample_variances_normal_gamma)
Filip Reierson filip.reierson@gmail.com (ORCID) (contributions: rtmvnorm)
Kenyon Ng kenyon.ng@gmail.com (ORCID) (contributions: rtmvnorm_hmc)
Useful links: